@@ -60,4 +60,8 @@ class V3ioFile(AbstractBufferedFile):
         """ Create remote file/upload """
         client: Client = self.fs._client
         container, path = split_container(self.path)
-        client.object.delete(container=container, path=path)
+        client.object.delete(
+            container=container,
+            path=path,
+            raise_for_status=v3io.dataplane.RaiseForStatus.never,
+        )
